@@ -81,7 +81,7 @@ NNS.ARMA <- function(variable,
 
   if(is.numeric(seasonal.factor) && dynamic) stop('Hmmm...Seems you have "seasonal.factor" specified and "dynamic = TRUE".  Nothing dynamic about static seasonal factors!  Please set "dynamic = FALSE" or "seasonal.factor = FALSE"')
 
-  if(any(class(variable)==c("tbl", "data.table"))) variable <- as.vector(unlist(variable))
+  if(any(class(variable)%in%c("tbl","data.table"))) variable <- as.vector(unlist(variable))
 
   if(sum(is.na(variable)) > 0) stop("You have some missing values, please address.")
 
@@ -92,7 +92,7 @@ NNS.ARMA <- function(variable,
   options(warn = -1)
 
 
-  if (is.null(ncores)) num_cores <- as.integer(parallel::detectCores()  - 1) else num_cores <- ncores
+  if(is.null(ncores)) num_cores <- as.integer(parallel::detectCores()  - 1) else num_cores <- ncores
 
   if(num_cores>1) doParallel::registerDoParallel(num_cores)
 
