@@ -38,9 +38,9 @@ NNS.caus <- function(x, y = NULL,
   orig.tau <- tau
   orig.plot <- plot
 
-  if(any(class(x)==c("tbl", "data.table")) && dim(x)[2]==1) x <- as.vector(unlist(x))
-  if(any(class(x)==c("tbl", "data.table"))) x <- as.data.frame(x)
-  if(!is.null(y) && any(class(y)==c("tbl", "data.table"))) y <- as.vector(unlist(y))
+  if(any(class(x)%in%c("tbl","data.table")) && dim(x)[2]==1) x <- as.vector(unlist(x))
+  if(any(class(x)%in%c("tbl","data.table"))) x <- as.data.frame(x)
+  if(!is.null(y) && any(class(y)%in%c("tbl","data.table"))) y <- as.vector(unlist(y))
 
 
   if(factor.2.dummy){
